<?xml version="1.0" encoding="UTF-8"?>
<?xml-stylesheet type="text/xsl" ?>
<xsl:stylesheet version="1.0" 
		xmlns:xsl="http://www.w3.org/1999/XSL/Transform" 
		xmlns="http://www.w3.org/1999/xhtml"
		xmlns:tsx="http://www.environment-agency.gov.uk/XMLSchemas/EATimeSeriesDataExchangeFormat" 
		xmlns:md="http://www.environment-agency.gov.uk/XMLSchemas/EAMetadataFormat"
		xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance"
		xmlns:xsd="http://www.w3.org/2001/XMLSchema" 
		xmlns:dc="http://purl.org/dc/elements/1.1/"
		xsi:schemaLocation="http://www.environment-agency.gov.uk/XMLSchemas/EATimeSeriesDataExchangeFormat EATimeSeriesDataExchangeFormat.xsd http://www.environment-agency.gov.uk/XMLSchemas/EAMetadataFormat EAMetadata.xsd">

<!-- =================================== -->
<!-- Match if 'True' ...                 -->

	<xsl:variable name="matchComments" select="'True'" />
	<xsl:variable name="sortSetofValues" select="'True'" />

<!-- =================================== -->

	<dc:Title>Standard XHTML mark-up for the EA time-series data standard (v3.5)</dc:Title>
	<dc:Date>2008-03-12</dc:Date>
	<dc:Description>Transform from Environment Agency Time-Series Data-Exchange Standard (TSX) documents (version 1.1 to 1.2) into XHTML v1.0</dc:Description>
	<dc:Relation>Files "EATimeSeriesDataExchangeFormat.xsd", "tsx_eaheader.jpg" and "Information.html" to be in the same directory as this stylesheet</dc:Relation>
	<dc:Creator>Chris Beales</dc:Creator>
	<dc:Format>text/xsl</dc:Format>
	<dc:Identifier>http://websites.chrisbeales.net/TSX/tsx-Trans_EA Standard XHTML.xsl</dc:Identifier>
	<dc:Language>en</dc:Language>
	<dc:Publisher>Chris Beales, Environment Agency</dc:Publisher>
	<dc:Rights>Copyright 2006-08 Environment Agency</dc:Rights>
	<dc:Type>XSL Stylesheet</dc:Type>
	<dc:Subject>XML, EATimeSeriesDataExchangeFormat, TSX, XHTML, HTML</dc:Subject>

<!-- =================================== -->

	<xsl:output 
		method="xml" 
		version="1.0" 
		encoding="iso-8859-1" 
		indent="yes" 
		omit-xml-declaration="no"
		doctype-system="http://www.w3.org/TR/xhtml1/DTD/xhtml1-strict.dtd"
		doctype-public="-//W3C//DTD XHTML 1.0 Strict//EN"
		media-type="text/html" />

	<xsl:variable name="firstColWidth" select="160" />
	<xsl:variable name="docRelPath">
		<xsl:value-of select="substring-before(substring-after(substring-after(/processing-instruction('xml-stylesheet'), 'href'), '&quot;'), 'tsx-Trans_EA Standard XHTML')" />
	</xsl:variable>

	<xsl:key name="kComment" match="//tsx:Comment" use="''" />

	<xsl:template match="/">
		<xsl:element name="html">
			<xsl:attribute name="xml:lang">en</xsl:attribute>
			<xsl:attribute name="lang">en</xsl:attribute>
			
			<xsl:element name="head">
				<xsl:element name="title">Time-series data file</xsl:element>				
				<!-- CSS stylesheet -->				
				<xsl:element name="link">
					<xsl:attribute name="href"><xsl:value-of select="concat($docRelPath, 'tsx.css')" /></xsl:attribute>
					<xsl:attribute name="rel">STYLESHEET</xsl:attribute>
					<xsl:attribute name="type">text/css</xsl:attribute>
				</xsl:element>
			</xsl:element> 

			<xsl:element name="body">

				<!-- Header -->

				<xsl:element name="div">
					<xsl:attribute name="id"><xsl:value-of select="'top'" /></xsl:attribute> 

					<xsl:element name="img">
						<xsl:attribute name="alt">
							<xsl:value-of select="concat('Environment Agency logo (', $docRelPath, 'ealogo.jpg)')" />
						</xsl:attribute>
						<xsl:attribute name="src">
							<xsl:value-of select="concat($docRelPath, 'ealogo.jpg')" />
						</xsl:attribute>
						<xsl:attribute name="class">logo</xsl:attribute>
					</xsl:element>
					
					<xsl:element name="h1">
						<xsl:attribute name="class">topText</xsl:attribute>
						<xsl:text>Time-series data exchange...</xsl:text>
					</xsl:element>
				</xsl:element>

				<!-- Main -->
				
				<xsl:element name="div">
					<xsl:attribute name="id">main</xsl:attribute>
						
					<xsl:apply-templates select="tsx:EATimeSeriesDataExchangeFormat"/>
				</xsl:element>  <!-- div -->
				
				<!-- Footer -->
				<xsl:element name="p">
					<xsl:attribute name="id"><xsl:value-of select="'foot'" /></xsl:attribute> 
					<xsl:attribute name="style">text-align: center</xsl:attribute>

					<xsl:element name="a">
						<xsl:attribute name="href"><xsl:value-of select="'#top'" /></xsl:attribute>
						<xsl:attribute name="title"><xsl:value-of select="'Link to top of document and the contents table'" /></xsl:attribute>
						<xsl:value-of select="'- Back to top -'" />
					</xsl:element>			
				</xsl:element>

				<xsl:element name="h2">Meanings for data/quality flags</xsl:element>

				<xsl:element name="p">
					<xsl:attribute name="class">endNote</xsl:attribute>

					<xsl:for-each select="document('EATimeSeriesDataExchangeFormat.xsd')/xsd:schema/xsd:simpleType[@name ='DataQualityFlagType']/xsd:annotation/xsd:documentation/*/*">

						<xsl:value-of select="concat(@flagNumber, ' = ', @flagName)"/>

						<xsl:if test="position() != last()">
							<xsl:value-of select="', '" />
						</xsl:if>
					</xsl:for-each>
				</xsl:element>

				<xsl:element name="p">
					<xsl:variable name="XSLfileName" select="document('')/*/dc:Title" />
					<xsl:value-of select="concat('This XHTML document has been created using the {', $XSLfileName, '} stylesheet. The XML data file is an Environment Agency Time-Series Data-Exchange Standard (TSX) document. For more information about the Standard, please refer to the Plain English Document located at ')" />
					<xsl:element name="a">
						<xsl:variable name="EAschemas">http://www.environment-agency.gov.uk/xmlschemas/</xsl:variable>
						<xsl:attribute name="href"><xsl:value-of select="$EAschemas" /></xsl:attribute>
						<xsl:attribute name="title">Link to the Schema pages of the Environment Agency's website</xsl:attribute>
						<xsl:value-of select="$EAschemas" />
					</xsl:element>
				</xsl:element>

			</xsl:element>  <!-- body -->
		</xsl:element>  <!-- html -->
	</xsl:template>

<!-- Main document -->
	<xsl:template match="tsx:EATimeSeriesDataExchangeFormat">
		<xsl:element name="br" />
		<xsl:element name="table">
			<xsl:attribute name="class">Metadata</xsl:attribute>
			
			<xsl:element name="colgroup">
				<xsl:element name="col">
					<xsl:attribute name="width"><xsl:value-of select="$firstColWidth" /></xsl:attribute> 
				</xsl:element>
				<xsl:element name="col" />
			</xsl:element>			

			<xsl:apply-templates select="md:Publisher"/>
			<xsl:apply-templates select="md:Source"/>
			<xsl:apply-templates select="md:Description"/>
			<xsl:apply-templates select="md:Creator"/>
			<xsl:apply-templates select="md:Date"/>
			<xsl:apply-templates select="md:Time"/>
			<xsl:apply-templates select="md:Identifier"/>
		</xsl:element>  <!-- table -->

		<xsl:if test="md:Publisher='Environment Agency'">
			<xsl:element name="p">
				Disclaimer: <xsl:text>&#34;</xsl:text>The information provided is based on that 
				currently available to the Agency. The Agency and its officers accept no liability 
				whatsoever for any loss or damage arising from the interpretation or use of the 
				information.<xsl:text>&#34;</xsl:text>
			</xsl:element>
		</xsl:if>

		<xsl:element name="p">
			<xsl:if test="$matchComments='True'">
				This stylesheet will map comments with values in the data tables.
			</xsl:if>

			If you wish to change to a different stylesheet, or if you are having problems viewing 
			data, please click 
			<xsl:element name="a">
				<xsl:attribute name="href">
					<xsl:value-of select="concat($docRelPath, 'tsx_Information.html')" />
				</xsl:attribute>
				<xsl:attribute name="title">Link to the {tsx_Information.html} document, which should be located in the same directory as the stylesheet</xsl:attribute>
				here (local)</xsl:element>
			or
			<xsl:element name="a">
				<xsl:attribute name="href">http://websites.chrisbeales.net/tsx/tsx_Information.html</xsl:attribute>
				<xsl:attribute name="title">Link to the live {tsx_Information.html} document on the internet</xsl:attribute>
				here (internet)</xsl:element>			
			for more information.
		</xsl:element>

		<xsl:element name="h2">Contents</xsl:element>
		
		<xsl:element name="ul">
			<xsl:apply-templates select="tsx:Station" mode="Contents" />

			<xsl:element name="li">
				<xsl:element name="a">
					<xsl:attribute name="href"><xsl:value-of select="'#foot'" /></xsl:attribute>
					<xsl:attribute name="title"><xsl:value-of select="'Link to bottom of document - flag definitions and other information'" /></xsl:attribute>
					<xsl:value-of select="'Flag definitions and information'" />
				</xsl:element>				
			</xsl:element>
		</xsl:element>

		<xsl:element name="hr" />

		<xsl:apply-templates select="tsx:Station"/>

	</xsl:template>

<!-- Contents table (Station) -->
	<xsl:template match="tsx:Station" mode="Contents">
		<xsl:element name="li">
			<xsl:value-of select="concat(@stationReference, ' - ', @stationName)" />

			<xsl:element name="ul">
				<xsl:apply-templates select="tsx:SetofValues" mode="Contents" />
			</xsl:element>
		</xsl:element>
	</xsl:template>

<!-- Contents table (Set-of-Values) -->
	<xsl:template match="tsx:SetofValues" mode="Contents">
		<xsl:variable name="contentSetOval">
			<xsl:value-of select="@parameter" />
			<xsl:if test="@qualifier">
				<xsl:value-of select="concat(' - ', @qualifier)" />
			</xsl:if>
			<xsl:value-of select="concat(' (', @period, '-', @dataType, ')')" />

			<xsl:if test="@productRef">			
				<xsl:value-of select="concat(' Product: &quot;', @productRef, '&quot;')" />
			</xsl:if>
		</xsl:variable>
	
		<xsl:element name="li">
			<xsl:element name="em">
				<xsl:if test="@startDate">
					<xsl:value-of select="concat(substring(@startDate, 9), '/', substring(@startDate, 6, 2), '/', substring(@startDate, 1, 4), ' ', @startTime)" />
				</xsl:if>
			</xsl:element>

			<xsl:if test="@endDate">
				<xsl:value-of select="' to '" />

				<xsl:element name="em">
					<xsl:value-of select="concat(substring(@endDate, 9), '/', substring(@endDate, 6, 2), '/', substring(@endDate, 1, 4))" />
					<xsl:if test="@endTime">
						<xsl:value-of select="concat(' ', @endTime)" />
					</xsl:if>
				</xsl:element>		
			</xsl:if>

			<xsl:element name="a">
				<xsl:attribute name="href"><xsl:value-of select="'#sov'" /><xsl:number level="any" /></xsl:attribute>
				<xsl:attribute name="title"><xsl:value-of select="concat('Link to ', $contentSetOval, ' set of values')" /></xsl:attribute>
				<xsl:value-of select="$contentSetOval" />
			</xsl:element>
			
		</xsl:element>					
	</xsl:template>

<!-- Metadata -->
	<xsl:template match="md:*">
		<xsl:element name="tr">
			<xsl:element name="td">
				<xsl:attribute name="class">titleCell</xsl:attribute>
				<xsl:value-of select="concat(local-name(.), ':')"/>
			</xsl:element>

			<xsl:variable name="mdValue">
				<xsl:value-of select="." />
			</xsl:variable>

			<xsl:element name="td">
				<xsl:attribute name="class">titleCell</xsl:attribute>
				<xsl:if test="local-name(.) = 'Date'">
					<xsl:value-of select="concat(substring($mdValue, 9), '/', substring($mdValue, 6, 2), '/', substring($mdValue, 1, 4))" />		
				</xsl:if>

				<xsl:if test="local-name(.) != 'Date'">				
					<xsl:value-of select="."/>
				</xsl:if>
			</xsl:element>
		</xsl:element>
	</xsl:template>
	
<!-- Station element -->
	<xsl:template match="tsx:Station">
		<xsl:apply-templates select="tsx:SetofValues"/>
		<xsl:element name="hr" />
	
	</xsl:template>

<!-- Set-of-values element -->
	<xsl:template match="tsx:SetofValues">
		<xsl:element name="p">
			<xsl:attribute name="id"><xsl:value-of select="'sov'" /><xsl:number level="any" /></xsl:attribute> 
			<xsl:attribute name="style">text-align: center</xsl:attribute>

			<xsl:element name="a">
				<xsl:attribute name="href"><xsl:value-of select="'#top'" /></xsl:attribute>
				<xsl:attribute name="title"><xsl:value-of select="'Link to top of document and the contents table'" /></xsl:attribute>
				<xsl:value-of select="'- Back to top -'" />
			</xsl:element>			
		</xsl:element>

	<!-- Station information... -->
		<xsl:element name="table">
			<xsl:attribute name="class">Station</xsl:attribute>

			<xsl:element name="colgroup">
				<xsl:element name="col">
					<xsl:attribute name="width"><xsl:value-of select="$firstColWidth" /></xsl:attribute> 
				</xsl:element>
				<xsl:element name="col" />
			</xsl:element>			

			<xsl:element name="tr">
				<xsl:element name="td">Station:</xsl:element>
				<xsl:element name="td">
					<xsl:value-of select="../@stationReference"/>
				</xsl:element>
			</xsl:element>

			<xsl:if test="../@stationName">
				<xsl:element name="tr">
					<xsl:element name="td">Name:</xsl:element>
					<xsl:element name="td"><xsl:value-of select="../@stationName"/></xsl:element>
				</xsl:element>
			</xsl:if>

			<xsl:if test="../@region">
				<xsl:element name="tr">
					<xsl:element name="td">Region:</xsl:element>
					<xsl:element name="td"><xsl:value-of select="../@region"/></xsl:element>
				</xsl:element>
			</xsl:if>
			
			<xsl:if test="../@ngr">
				<xsl:element name="tr">
					<xsl:element name="td">NGR:</xsl:element>
					<xsl:element name="td"><xsl:value-of select="../@ngr"/></xsl:element>
				</xsl:element>
			</xsl:if>			
		</xsl:element>	<!-- table -->
		
		<xsl:element name="br" />
		
	<!-- Set of values information... -->
		<xsl:element name="table">
			<xsl:attribute name="class">SetofValues</xsl:attribute> 

			<xsl:element name="colgroup">
				<xsl:element name="col">
					<xsl:attribute name="width"><xsl:value-of select="$firstColWidth" /></xsl:attribute> 
				</xsl:element>
				<xsl:element name="col" />
			</xsl:element>			

			<xsl:element name="tr">
				<xsl:element name="td">Parameter:</xsl:element>
				<xsl:element name="td">
					<xsl:value-of select="@parameter"/>
					<xsl:if test="@qualifier">   (<xsl:value-of select="@qualifier"/>)</xsl:if>
				</xsl:element>
			</xsl:element>

			<xsl:element name="tr">
				<xsl:element name="td">Data Type:</xsl:element>
				<xsl:element name="td">
					<xsl:value-of select="@period"/> - <xsl:value-of select="@dataType"/>
					<xsl:if test="@interval">&#9;  (Interval: <xsl:value-of select="@interval"/>)</xsl:if>
				</xsl:element>
			</xsl:element>

			<xsl:element name="tr">
				<xsl:element name="td">Units:</xsl:element>
				<xsl:element name="td"><xsl:value-of select="@units"/></xsl:element>
			</xsl:element>

			<xsl:if test="@pointReference">
				<xsl:element name="tr">
					<xsl:element name="td">Point Ref:</xsl:element>
					<xsl:element name="td"><xsl:value-of select="@pointReference"/></xsl:element>
				</xsl:element>
			</xsl:if>

			<xsl:if test="@characteristic">
				<xsl:element name="tr">
					<xsl:element name="td">Characteristic:</xsl:element>
					<xsl:element name="td"><xsl:value-of select="@characteristic"/></xsl:element>
				</xsl:element>
			</xsl:if>

			<xsl:if test="@productRef">
				<xsl:element name="tr">
					<xsl:element name="td">Product Ref:</xsl:element>
					<xsl:element name="td"><xsl:value-of select="@productRef"/></xsl:element>
				</xsl:element>
			</xsl:if>

			<xsl:if test="@dayOrigin">
				<xsl:element name="tr">
					<xsl:element name="td">Day Origin:</xsl:element>
					<xsl:element name="td"><xsl:value-of select="@dayOrigin"/></xsl:element>
				</xsl:element>
			</xsl:if>

			<xsl:if test="@valuesPerDay">
				<xsl:element name="tr">
					<xsl:element name="td">Values Per Day:</xsl:element>
					<xsl:element name="td"><xsl:value-of select="@valuesPerDay"/></xsl:element>
				</xsl:element>
			</xsl:if>						
		</xsl:element>  <!-- table -->

		<xsl:element name="table">
			<xsl:attribute name="class">SetofValues</xsl:attribute> 

			<xsl:element name="colgroup">
				<xsl:element name="col">
					<xsl:attribute name="width"><xsl:value-of select="$firstColWidth" /></xsl:attribute> 
				</xsl:element>
				<xsl:element name="col">
					<xsl:attribute name="width">200</xsl:attribute> 
				</xsl:element>	
				<xsl:element name="col">
					<xsl:attribute name="width"><xsl:value-of select="$firstColWidth" /></xsl:attribute> 
				</xsl:element>
				<xsl:element name="col" />
			</xsl:element>			

			<xsl:if test="@startDate or @startTime">
				<xsl:element name="tr">
					<xsl:choose>
						<xsl:when test="@startDate">
							<xsl:element name="td">Start Date:</xsl:element>
							<xsl:element name="td"><xsl:value-of select="@startDate"/></xsl:element>
						</xsl:when>						
						<xsl:otherwise>
							<xsl:element name="td" />
							<xsl:element name="td" />
						</xsl:otherwise>
					</xsl:choose>
					<xsl:choose>
						<xsl:when test="@startTime">
							<xsl:element name="td">Start Time:</xsl:element>
							<xsl:element name="td"><xsl:value-of select="@startTime"/></xsl:element>
						</xsl:when>						
						<xsl:otherwise>
							<xsl:element name="td" />
							<xsl:element name="td" />
						</xsl:otherwise>
					</xsl:choose>
				</xsl:element>
			</xsl:if>						

			<xsl:if test="@endDate or @endTime">
				<xsl:element name="tr">
					<xsl:choose>
						<xsl:when test="@endDate">
							<xsl:element name="td">End Date:</xsl:element>
							<xsl:element name="td"><xsl:value-of select="@endDate"/></xsl:element>
						</xsl:when>						
						<xsl:otherwise>
							<xsl:element name="td" />
							<xsl:element name="td" />
						</xsl:otherwise>
					</xsl:choose>
					<xsl:choose>
						<xsl:when test="@endTime">
							<xsl:element name="td">End Time:</xsl:element>
							<xsl:element name="td"><xsl:value-of select="@endTime"/></xsl:element>
						</xsl:when>						
						<xsl:otherwise>
							<xsl:element name="td" />
							<xsl:element name="td" />
						</xsl:otherwise>
					</xsl:choose>
				</xsl:element>
			</xsl:if>						
		</xsl:element>  <!-- table -->
		
		<xsl:element name="br" />

	<!-- Build values table -->
		<xsl:element name="table">
			<xsl:attribute name="class">Values</xsl:attribute> 

			<xsl:element name="colgroup">
				<xsl:element name="col" />
				<xsl:element name="col" />
				<xsl:element name="col" />
				<xsl:element name="col" />
				<xsl:if test="$matchComments = 'True'">
					<xsl:element name="col" />
				</xsl:if>
			</xsl:element>			
			
			<xsl:element name="tr">
				<xsl:element name="th">Date/Time</xsl:element>
				<xsl:element name="th">Value</xsl:element>
				<xsl:element name="th">Primary Flag</xsl:element>
				<xsl:element name="th">Other Flags</xsl:element>					
				<xsl:if test="$matchComments = 'True'">
					<xsl:element name="th">Comments</xsl:element>					
				</xsl:if>
			</xsl:element>

			<xsl:choose>
				<xsl:when test="$sortSetofValues = 'True'">
					<xsl:apply-templates select="tsx:Value">
						<xsl:sort select="concat(@date, ' ',  @time)" order="ascending" data-type="text" />      	
					</xsl:apply-templates>
				</xsl:when>
				
				<xsl:otherwise>
					<xsl:apply-templates select="tsx:Value" />
				</xsl:otherwise>
			</xsl:choose>
			
		</xsl:element>  <!-- table -->

		<xsl:if test="count(./tsx:Comment) != 0">
			<xsl:element name="h2">List of comments</xsl:element>
		</xsl:if>

		<xsl:choose>
			<xsl:when test="$sortSetofValues = 'True'">
				<xsl:apply-templates select="tsx:Comment">
					<xsl:sort select="concat(@startDate, ' ',  @startTime, ' ', @endDate, ' ',  @endTime)" order="ascending" data-type="text" />      	
				</xsl:apply-templates>
			</xsl:when>

			<xsl:otherwise>
				<xsl:apply-templates select="tsx:Comment" />
			</xsl:otherwise>
		</xsl:choose>

	</xsl:template>

<!-- Value element -->
	<xsl:template match="tsx:Value">
		<xsl:variable name="primaryFlag">
			<xsl:choose>
				<xsl:when test="@flag1=1">Good</xsl:when>
				<xsl:when test="@flag1=2">Suspect</xsl:when>
				<xsl:when test="@flag1=4">Unchecked</xsl:when>
				<xsl:when test="@flag1=5">Missing</xsl:when>
				<xsl:otherwise><xsl:value-of select="@flag1"/></xsl:otherwise>
			</xsl:choose>
		</xsl:variable>

	<!-- Set colours for output - if primary quality (flag1) contains 
			Good/Suspect/Unchecked/Missing information, otherwise assume Good -->
		<xsl:variable name="dataColour">
			<xsl:choose>
				<xsl:when test="$primaryFlag='Suspect'">S</xsl:when>
				<xsl:when test="$primaryFlag='Missing'">M</xsl:when>
				<xsl:when test="$primaryFlag='Unchecked'">U</xsl:when>
				<xsl:otherwise>G</xsl:otherwise>
			</xsl:choose>
		</xsl:variable>

		<xsl:variable name="otherFlags">
			<xsl:if test="@percentFlag1">&#160;(<xsl:value-of select="@percentFlag1"/>%)</xsl:if>
			<xsl:if test="@flag2">,<xsl:value-of select="@flag2"/></xsl:if>
			<xsl:if test="@percentFlag2">&#160;(<xsl:value-of select="@percentFlag2"/>%)</xsl:if>
			<xsl:if test="@flag3">,<xsl:value-of select="@flag3"/></xsl:if>
			<xsl:if test="@percentFlag3">&#160;(<xsl:value-of select="@percentFlag3"/>%)</xsl:if>
			<xsl:if test="@flag4">,<xsl:value-of select="@flag4"/></xsl:if>
			<xsl:if test="@percentFlag4">&#160;(<xsl:value-of select="@percentFlag4"/>%)</xsl:if>
			<xsl:if test="@flag5">,<xsl:value-of select="@flag5"/></xsl:if>
			<xsl:if test="@percentFlag5">&#160;(<xsl:value-of select="@percentFlag5"/>%)</xsl:if>
			<xsl:if test="@flag6">,<xsl:value-of select="@flag6"/></xsl:if>
			<xsl:if test="@percentFlag6">&#160;(<xsl:value-of select="@percentFlag6"/>%)</xsl:if>
			<xsl:if test="@flag7">,<xsl:value-of select="@flag7"/></xsl:if>
			<xsl:if test="@percentFlag7">&#160;(<xsl:value-of select="@percentFlag7"/>%)</xsl:if>
			<xsl:if test="@flag8">,<xsl:value-of select="@flag8"/></xsl:if>
			<xsl:if test="@percentFlag8">&#160;(<xsl:value-of select="@percentFlag8"/>%)</xsl:if>
			<xsl:if test="@flag9">,<xsl:value-of select="@flag9"/></xsl:if>
			<xsl:if test="@percentFlag9">&#160;(<xsl:value-of select="@percentFlag9"/>%)</xsl:if>
			<xsl:if test="@flag10">,<xsl:value-of select="@flag10"/></xsl:if>
			<xsl:if test="@percentFlag10">&#160;(<xsl:value-of select="@percentFlag10"/>%)</xsl:if>
		</xsl:variable>

		<xsl:element name="tr">
			<xsl:attribute name="class"><xsl:value-of select="$dataColour" /></xsl:attribute>

			<xsl:variable name="vDate" select="@date" />
			<xsl:element name="td">
				<xsl:value-of select="concat(substring($vDate, 9), '/', substring($vDate, 6, 2), '/', substring($vDate, 1, 4))" />		
				<xsl:if test="@time">
					<xsl:text disable-output-escaping="yes">&amp;#160;</xsl:text>
					<xsl:value-of select="@time"/>
				</xsl:if>
			</xsl:element>
			<xsl:element name="td">
				<xsl:value-of select="."/>
			</xsl:element>
			<xsl:element name="td">
				<xsl:choose>
					<xsl:when test="$primaryFlag != ''"><xsl:value-of select="$primaryFlag"/></xsl:when>
					<xsl:otherwise>-</xsl:otherwise>
				</xsl:choose>
			</xsl:element>
			<xsl:element name="td">
				<xsl:choose>
					<xsl:when test="$otherFlags != ''"><xsl:value-of select="substring($otherFlags,2)"/></xsl:when>
					<xsl:otherwise>-</xsl:otherwise>
				</xsl:choose>
			</xsl:element>

			<xsl:if test="$matchComments = 'True'">
				<xsl:variable name="testDayO">
					<xsl:value-of select="concat(substring(../@dayOrigin,1,2), substring(../@dayOrigin,4,2), substring(../@dayOrigin,7,2))" />
				</xsl:variable>

				<xsl:variable name="timeTest">
					<xsl:choose>
						<xsl:when test="@time">
							 <xsl:value-of select="concat(substring(@date,1,4), substring(@date,6,2), substring(@date,9,2), '.', substring(@time,1,2), substring(@time,4,2), substring(@time,7,2))" />
						</xsl:when>

						<xsl:when test="(../@dayOrigin) and not(@time)">					
							<xsl:value-of select="concat(substring(@date,1,4), substring(@date,6,2), substring(@date,9,2), '.', $testDayO)" />
						</xsl:when>				

						<xsl:otherwise>
							<xsl:value-of select="concat(substring(@date,1,4), substring(@date,6,2), substring(@date,9,2))" />
						</xsl:otherwise>
					</xsl:choose>
				</xsl:variable>

				<xsl:variable name="SoV" select="ancestor::*[1]" />

				<xsl:element name="td">
					<xsl:apply-templates select="key('kComment', '')[(substring(concat(substring(@startDate,1,4), substring(@startDate,6,2), substring(@startDate,9,2), '.', substring(@startTime,1,2), substring(@startTime,4,2), substring(@startTime,7,2), $testDayO), 1, 15) &lt;= $timeTest) and (substring(concat(substring(@endDate,1,4), substring(@endDate,6,2), substring(@endDate,9,2), '.', substring(@endTime,1,2), substring(@endTime,4,2), substring(@endTime,7,2), $testDayO), 1, 15) &gt;= $timeTest) and ($SoV = ancestor::*[1])]" mode="InTable" />
				</xsl:element>		
			</xsl:if>

		</xsl:element>		<!-- tr -->
	</xsl:template>
		
	<xsl:template match="tsx:Comment" mode="InTable">
		<xsl:value-of select="." />
		<xsl:if test="position() != last()"><xsl:text> | </xsl:text></xsl:if>
	</xsl:template>

<!-- Comment list at end -->
	<xsl:template match="tsx:Comment">
		<xsl:element name="p">
			<xsl:if test="@startDate or @startTime">
				(Start: <xsl:element name="em"><xsl:value-of select="@startDate"/> 
				<xsl:text disable-output-escaping="yes">&amp;#160;</xsl:text>
				<xsl:value-of select="@startTime"/></xsl:element>)
			</xsl:if>
			
			<xsl:if test="@endDate or @endTime">
				(End: <xsl:element name="em"><xsl:value-of select="@endDate"/> 
				<xsl:text disable-output-escaping="yes">&amp;#160;</xsl:text>
				<xsl:value-of select="@endTime"/></xsl:element>)
			</xsl:if>
			
			<xsl:value-of select="."/>
			<!-- xsl:value-of select="concat(substring(@startDate,1,4), substring(@startDate,6,2), substring(@startDate,9,2), '.', substring(@startTime,1,2), substring(@startTime,4,2), substring(@startTime,7,2))" / -->
		</xsl:element>  <!-- p -->
	</xsl:template>

</xsl:stylesheet>
